@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0801';
+our $VERSION = '0.0802';
 
 use Bit::Vector;
 use DBI;
@@ -232,7 +232,7 @@ sub score {
 sub _familiarity {
     my ( $self, $mask ) = @_;
 
-    my @chunks = split /(0+)/, $mask;
+    my @chunks = grep { $_ ne "" } split /(0+)/, $mask;
 
     # Figure out how many chars are only 1s and
     # Figure out how many chunks are made up of 1s:
@@ -416,7 +416,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.0801
+version 0.0802
 
 =head1 SYNOPSIS
 
